@@ -34,12 +34,12 @@ class MINUETINTERFACES_EXPORT IUiController : public QObject
     Q_OBJECT
 
 public:
-    virtual ~IUiController() override;
+    virtual ~IUiController() override = default;
 
     virtual QString errorString() const = 0;
 
 protected:
-    explicit IUiController(QObject *parent = 0);
+    explicit IUiController(QObject *parent = nullptr);
 };
 
 }
